==> hex_core-0.4.0.tar.gz: hex_registry.md <==


# Module hex_registry #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-private_key">private_key()</a> ###


<pre><code>
private_key() = <a href="public_key.md#type-rsa_private_key">public_key:rsa_private_key()</a> | binary()
</code></pre>




### <a name="type-public_key">public_key()</a> ###


<pre><code>
public_key() = <a href="public_key.md#type-rsa_public_key">public_key:rsa_public_key()</a> | binary()
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#decode_and_verify_signed-2">decode_and_verify_signed/2</a></td><td>
Decode message created with sign_protobuf/2 and verify it against public key.</td></tr><tr><td valign="top"><a href="#decode_names-2">decode_names/2</a></td><td>
Decode message created with encode_names/1.</td></tr><tr><td valign="top"><a href="#decode_package-3">decode_package/3</a></td><td>
Decode message created with encode_package/1.</td></tr><tr><td valign="top"><a href="#decode_signed-1">decode_signed/1</a></td><td>
Decode message created with sign_protobuf/2 without verification.</td></tr><tr><td valign="top"><a href="#decode_versions-2">decode_versions/2</a></td><td>
Decode message created with encode_versions/1.</td></tr><tr><td valign="top"><a href="#encode_names-1">encode_names/1</a></td><td>
Encode Names message.</td></tr><tr><td valign="top"><a href="#encode_package-1">encode_package/1</a></td><td>
Encode Package message.</td></tr><tr><td valign="top"><a href="#encode_versions-1">encode_versions/1</a></td><td>
Encode Versions message.</td></tr><tr><td valign="top"><a href="#sign-2">sign/2</a></td><td>
Signs binary with given private key.</td></tr><tr><td valign="top"><a href="#sign_protobuf-2">sign_protobuf/2</a></td><td>
Encode Signed message.</td></tr><tr><td valign="top"><a href="#verify-3">verify/3</a></td><td>
Verifies binary against signature and a public key.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="decode_and_verify_signed-2"></a>

### decode_and_verify_signed/2 ###

<pre><code>
decode_and_verify_signed(Signed::map(), PublicKey::<a href="#type-public_key">public_key()</a>) -&gt; {ok, binary()} | {error, term()}
</code></pre>
<br />

Decode message created with sign_protobuf/2 and verify it against public key.

<a name="decode_names-2"></a>

### decode_names/2 ###

`decode_names(Payload, Repository) -> any()`

Decode message created with encode_names/1.

<a name="decode_package-3"></a>

### decode_package/3 ###

`decode_package(Payload, Repository, Package) -> any()`

Decode message created with encode_package/1.

<a name="decode_signed-1"></a>

### decode_signed/1 ###

`decode_signed(Signed) -> any()`

Decode message created with sign_protobuf/2 without verification.

<a name="decode_versions-2"></a>

### decode_versions/2 ###

`decode_versions(Payload, Repository) -> any()`

Decode message created with encode_versions/1.

<a name="encode_names-1"></a>

### encode_names/1 ###

`encode_names(Names) -> any()`

Encode Names message.

<a name="encode_package-1"></a>

### encode_package/1 ###

`encode_package(Package) -> any()`

Encode Package message.

<a name="encode_versions-1"></a>

### encode_versions/1 ###

`encode_versions(Versions) -> any()`

Encode Versions message.

<a name="sign-2"></a>

### sign/2 ###

<pre><code>
sign(Binary::binary(), PrivateKey::<a href="#type-private_key">private_key()</a>) -&gt; binary()
</code></pre>
<br />

Signs binary with given private key.

<a name="sign_protobuf-2"></a>

### sign_protobuf/2 ###

`sign_protobuf(Payload, PrivateKey) -> any()`

Encode Signed message.

<a name="verify-3"></a>

### verify/3 ###

<pre><code>
verify(Binary::binary(), Signature::binary(), PublicKey::<a href="#type-public_key">public_key()</a>) -&gt; boolean() | {error, term()}
</code></pre>
<br />

Verifies binary against signature and a public key.

==> hex_core-0.6.6.tar.gz: hex_registry.md <==


# Module hex_registry #
* [Data Types](#types)
* [Function Index](#index)
* [Function Details](#functions)

<a name="types"></a>

## Data Types ##




### <a name="type-private_key">private_key()</a> ###


<pre><code>
private_key() = <a href="public_key.md#type-rsa_private_key">public_key:rsa_private_key()</a> | binary()
</code></pre>




### <a name="type-public_key">public_key()</a> ###


<pre><code>
public_key() = <a href="public_key.md#type-rsa_public_key">public_key:rsa_public_key()</a> | binary()
</code></pre>

<a name="index"></a>

## Function Index ##


<table width="100%" border="1" cellspacing="0" cellpadding="2" summary="function index"><tr><td valign="top"><a href="#decode_and_verify_signed-2">decode_and_verify_signed/2</a></td><td>
Decode message created with sign_protobuf/2 and verify it against public key.</td></tr><tr><td valign="top"><a href="#decode_names-2">decode_names/2</a></td><td>
Decode message created with encode_names/1.</td></tr><tr><td valign="top"><a href="#decode_package-3">decode_package/3</a></td><td>
Decode message created with encode_package/1.</td></tr><tr><td valign="top"><a href="#decode_signed-1">decode_signed/1</a></td><td>
Decode message created with sign_protobuf/2 without verification.</td></tr><tr><td valign="top"><a href="#decode_versions-2">decode_versions/2</a></td><td>
Decode message created with encode_versions/1.</td></tr><tr><td valign="top"><a href="#encode_names-1">encode_names/1</a></td><td>
Encode Names message.</td></tr><tr><td valign="top"><a href="#encode_package-1">encode_package/1</a></td><td>
Encode Package message.</td></tr><tr><td valign="top"><a href="#encode_versions-1">encode_versions/1</a></td><td>
Encode Versions message.</td></tr><tr><td valign="top"><a href="#sign-2">sign/2</a></td><td>
Signs binary with given private key.</td></tr><tr><td valign="top"><a href="#sign_protobuf-2">sign_protobuf/2</a></td><td>
Encode Signed message.</td></tr><tr><td valign="top"><a href="#verify-3">verify/3</a></td><td>
Verifies binary against signature and a public key.</td></tr></table>


<a name="functions"></a>

## Function Details ##

<a name="decode_and_verify_signed-2"></a>

### decode_and_verify_signed/2 ###

<pre><code>
decode_and_verify_signed(Signed::binary(), PublicKey::<a href="#type-public_key">public_key()</a>) -&gt; {ok, binary()} | {error, term()}
</code></pre>
<br />

Decode message created with sign_protobuf/2 and verify it against public key.

<a name="decode_names-2"></a>

### decode_names/2 ###

`decode_names(Payload, Repository) -> any()`

Decode message created with encode_names/1.

<a name="decode_package-3"></a>

### decode_package/3 ###

`decode_package(Payload, Repository, Package) -> any()`

Decode message created with encode_package/1.

<a name="decode_signed-1"></a>

### decode_signed/1 ###

`decode_signed(Signed) -> any()`

Decode message created with sign_protobuf/2 without verification.

<a name="decode_versions-2"></a>

### decode_versions/2 ###

`decode_versions(Payload, Repository) -> any()`

Decode message created with encode_versions/1.

<a name="encode_names-1"></a>

### encode_names/1 ###

`encode_names(Names) -> any()`

Encode Names message.

<a name="encode_package-1"></a>

### encode_package/1 ###

`encode_package(Package) -> any()`

Encode Package message.

<a name="encode_versions-1"></a>

### encode_versions/1 ###

`encode_versions(Versions) -> any()`

Encode Versions message.

<a name="sign-2"></a>

### sign/2 ###

<pre><code>
sign(Binary::binary(), PrivateKey::<a href="#type-private_key">private_key()</a>) -&gt; binary()
</code></pre>
<br />

Signs binary with given private key.

<a name="sign_protobuf-2"></a>

### sign_protobuf/2 ###

`sign_protobuf(Payload, PrivateKey) -> any()`

Encode Signed message.

<a name="verify-3"></a>

### verify/3 ###

<pre><code>
verify(Binary::binary(), Signature::binary(), PublicKey::<a href="#type-public_key">public_key()</a>) -&gt; boolean() | {error, term()}
</code></pre>
<br />

Verifies binary against signature and a public key.
